import { Component, OnInit } from '@angular/core';
import { JokeService } from '../services/joke.service';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { HttpClient } from '@angular/common/http';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatSelectModule } from '@angular/material/select';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatDialogModule } from '@angular/material/dialog';
import { ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-add-joke',
  imports: [
    CommonModule,
    MatFormFieldModule,
    MatInputModule,
    MatSelectModule,
    MatButtonModule,
    MatCardModule,
    MatDialogModule,
    ReactiveFormsModule
  ],
  templateUrl: './add-joke.component.html',
  styleUrls: ['./add-joke.component.css']
})
export class AddJokeComponent implements OnInit {
  jokeForm!: FormGroup; 
  categories: string[] = []; 
  message: string = ''; 
  error: string = ''; 

  constructor(
    private jokeService: JokeService,
    private fb: FormBuilder,
    private http: HttpClient
  ) {}

  ngOnInit(): void {
    
    this.jokeForm = this.fb.group({
      creator: ['', Validators.required], 
      joke: ['', Validators.required], 
      category: ['', Validators.required] 
    });

    
    this.fetchCategories();
  }

  fetchCategories(): void {
    
    this.http.get<any>('http://linux.kosickaakademia.sk:5123/get_category').subscribe({
      next: (response) => {
        this.categories = response.categories; 
      },
      error: (err) => {
        this.error = 'Failed to load categories. Please try again later.'; 
      }
    });
  }

  submitJoke(): void {
    
    if (this.jokeForm.invalid) {
      this.error = 'All fields are required.';
      return;
    }

    const jokePayload = {
      joke: this.jokeForm.value.joke,
      category: this.jokeForm.value.category,
      creator: this.jokeForm.value.creator
    };

    
    this.jokeService.addJoke(jokePayload).subscribe({
      next: (response) => {
        this.message = response.message || 'Joke added successfully!'; 
        this.error = ''; 
        this.jokeForm.reset(); 
      },
      error: (err) => {
        this.error = 'Failed to add joke. Please try again later.'; 
        this.message = ''; 
      }
    });
  }
}
