import { CommonModule } from '@angular/common';
import { Component, OnInit } from '@angular/core';
import { MatCardModule } from '@angular/material/card';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatSelectModule } from '@angular/material/select';
import { Inject } from '@angular/core';
import { JokeService } from '../services/joke.service';

@Component({
  selector: 'app-categories',
  imports: [
    MatFormFieldModule,
    MatSelectModule,
    MatCardModule,
    CommonModule
  ],
  templateUrl: './categories.component.html',
  styleUrl: './categories.component.css'
})
export class CategoriesComponent implements OnInit {
  categories: string[] = [];
  selectedCategory: string = '';
  jokes: { joke: string }[] = [];
  error: string = '';

  constructor(@Inject(JokeService) private jokeService: JokeService) {}

  ngOnInit(): void {
    this.fetchCategories();
  }

  fetchCategories(): void {
    this.jokeService.getCategories().subscribe({
      next: (response) => {
        this.categories = response.categories;
      },
      error: (err) => {
        this.error = 'Failed to load categories. Please try again later.';
      }
    });
  }

  onCategoryChange(category: string): void {
    this.selectedCategory = category;
    this.fetchJokesByCategory(category);
  }

  fetchJokesByCategory(category: string): void {
    this.jokeService.getJokesByCategory(category).subscribe({
      next: (response) => {
        this.jokes = response.jokes;
      },
      error: (err) => {
        this.error = 'Failed to load jokes. Please try again later.';
      }
    });
  }
}